﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Grids.Primitives;
using Infragistics.Controls.Grids;

namespace ChildBandStyling
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            
            for (int i = 0; i < 10; i++)
			{
                Data d =  new Data 
                {
                    Contact = "Cont " + (i % 4),
                    Description = "Desc " + i,
                    Anschrift = "Some other info " + i,
                    Tel = "0883" + i+ i+ i+ i+ i+ i,
                    ChildData = new ObservableCollection<Data>()
                };

                for (int j = 0; j < 5; j++)
                {
                    d.ChildData.Add(
                        new Data
                        {
                            Contact = "Child " + (i + j),
                            Description = "Child Desc " + j,
                            Anschrift = "Some some some" + i + j,
                            Tel = "0899" + i + j + i + j + i + j
                        });
                }
                data.Add(d);
			}

            DataContext = data;
            // The column grouping is defined by code, 
            // because I could not figure out how to do this by XAML
            // when using ColumnLayouts...
            ContactGrid.GroupBySettings.GroupByColumns.Add(ContactColumn);
            
        }

        void CellsPanel_Loaded(object sender, RoutedEventArgs e)
        {
            HeaderRow row = (sender as CellsPanel).Row as HeaderRow;

            if (row != null && row.Manager.ParentRow != null && row.Manager.ParentRow.RowType == RowType.ColumnLayoutHeaderRow)
                (sender as CellsPanel).Height = 0;
        }

        
    }

    public class ChildMargeCellBackgroundConverter : IMultiValueConverter
    {
        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            Data d = values[0] as Data;
            XamGrid grid = values[1] as XamGrid;
            Cell hovered = values[2] as Cell;
            Cell active = values[3] as Cell;

            if (d != null && grid != null)
            {
                if (active != null)
                {
                    if ((active.Row.Data as Data).Contact == d.Contact)
                    {
                        return new SolidColorBrush((Color)ColorConverter.ConvertFromString("#FFD5EAF2"));
                    }
                }

                if (hovered != null && (active == null || (active != null && active != hovered)))
                {
                    if ((hovered.Row.Data as Data).Contact == d.Contact)
                    {
                        return new SolidColorBrush((Color)ColorConverter.ConvertFromString("#FFE6EFF7"));
                    }
                }
                Row row = GetChildRowFromDataItem(grid.Rows, d, null);
                if (row != null)
                {
                    if (row.Manager.ParentRow != null && row.Manager.ParentRow.RowType == RowType.ColumnLayoutHeaderRow)
                        return new SolidColorBrush(Colors.Yellow);
                }
            }

            return new SolidColorBrush(Colors.White);
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }

        internal Row GetChildRowFromDataItem(RowCollection rows, object data, Row result)
        {
            if (result != null)
                return result;
            foreach (Row row in rows)
            {
                if (row.Data.Equals(data))
                {
                    result = row;
                }
                else
                {
                    foreach (ChildBand band in row.ChildBands)
                    {
                        result = GetChildRowFromDataItem(band.Rows, data, result);
                    }
                }
            }

            return result;
        }
    }

    public class ChildVisibilityConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class Data
    {
        public string Contact { get; set; }
        public string Description { get; set; }
        public string Anschrift { get; set; }
        public string Tel { get; set; }

        public ObservableCollection<Data> ChildData { get; set; }
    }

    public class XamGridEx : XamGrid
    {
        public XamGridEx()
        { 
            //base.MouseOverCell     
            
        }

        private CellBase lastHoveredCell;
        public CellBase LastHoveredCell
        {
            get
            {
                return lastHoveredCell;
            }
            private set
            {
                lastHoveredCell = value;
                OnPropertyChanged("LastHoveredCell");
            }
        }

        protected override void OnMouseMove(MouseEventArgs e)
        {
            base.OnMouseMove(e);
            if (MouseOverCell != LastHoveredCell)
                LastHoveredCell = MouseOverCell;
        }

        protected override void OnActiveCellChanged()
        {
            base.OnActiveCellChanged();
            OnPropertyChanged("ActiveCell");
        }
    }
}
